==> zio-aws-managedblockchain_2.12-5.17.104.7-sources.jar: zio/aws/managedblockchain/ManagedBlockchainMock.scala <==
package zio.aws.managedblockchain
import zio.aws.managedblockchain.model.GetMemberResponse.ReadOnly
import zio.aws.core.AwsError
import zio.aws.core.aspects.AwsCallAspect
import zio.{IO, ZEnvironment, URLayer}
import zio.aws.managedblockchain.model.{
  CreateMemberRequest,
  UpdateMemberRequest,
  GetNetworkRequest,
  RejectInvitationRequest,
  ListProposalVotesRequest,
  ListNodesRequest,
  ListMembersRequest,
  ListProposalsRequest,
  ListTagsForResourceRequest,
  UpdateNodeRequest,
  GetProposalRequest,
  CreateProposalRequest,
  GetMemberRequest,
  DeleteNodeRequest,
  ListInvitationsRequest,
  CreateNodeRequest,
  VoteOnProposalRequest,
  DeleteMemberRequest,
  UntagResourceRequest,
  GetNodeRequest,
  ListNetworksRequest,
  TagResourceRequest,
  CreateNetworkRequest
}
import software.amazon.awssdk.services.managedblockchain.ManagedBlockchainAsyncClient
import zio.stream.ZStream
import zio.test.mock.{Proxy, Mock}
object ManagedBlockchainMock extends Mock[ManagedBlockchain] {
  object ListProposals
      extends Stream[
        ListProposalsRequest,
        AwsError,
        zio.aws.managedblockchain.model.ProposalSummary.ReadOnly
      ]
  object ListProposalsPaginated
      extends Effect[
        ListProposalsRequest,
        AwsError,
        zio.aws.managedblockchain.model.ListProposalsResponse.ReadOnly
      ]
  object GetNetwork
      extends Effect[
        GetNetworkRequest,
        AwsError,
        zio.aws.managedblockchain.model.GetNetworkResponse.ReadOnly
      ]
  object CreateNode
      extends Effect[
        CreateNodeRequest,
        AwsError,
        zio.aws.managedblockchain.model.CreateNodeResponse.ReadOnly
      ]
  object CreateMember
      extends Effect[
        CreateMemberRequest,
        AwsError,
        zio.aws.managedblockchain.model.CreateMemberResponse.ReadOnly
      ]
  object UpdateNode
      extends Effect[
        UpdateNodeRequest,
        AwsError,
        zio.aws.managedblockchain.model.UpdateNodeResponse.ReadOnly
      ]
  object CreateNetwork
      extends Effect[
        CreateNetworkRequest,
        AwsError,
        zio.aws.managedblockchain.model.CreateNetworkResponse.ReadOnly
      ]
  object GetNode
      extends Effect[
        GetNodeRequest,
        AwsError,
        zio.aws.managedblockchain.model.GetNodeResponse.ReadOnly
      ]
  object DeleteNode
      extends Effect[
        DeleteNodeRequest,
        AwsError,
        zio.aws.managedblockchain.model.DeleteNodeResponse.ReadOnly
      ]
  object ListMembers
      extends Stream[
        ListMembersRequest,
        AwsError,
        zio.aws.managedblockchain.model.MemberSummary.ReadOnly
      ]
  object ListMembersPaginated
      extends Effect[
        ListMembersRequest,
        AwsError,
        zio.aws.managedblockchain.model.ListMembersResponse.ReadOnly
      ]
  object GetProposal
      extends Effect[
        GetProposalRequest,
        AwsError,
        zio.aws.managedblockchain.model.GetProposalResponse.ReadOnly
      ]
  object UpdateMember
      extends Effect[
        UpdateMemberRequest,
        AwsError,
        zio.aws.managedblockchain.model.UpdateMemberResponse.ReadOnly
      ]
  object UntagResource
      extends Effect[
        UntagResourceRequest,
        AwsError,
        zio.aws.managedblockchain.model.UntagResourceResponse.ReadOnly
      ]
  object GetMember extends Effect[GetMemberRequest, AwsError, ReadOnly]
  object ListNetworks
      extends Stream[
        ListNetworksRequest,
        AwsError,
        zio.aws.managedblockchain.model.NetworkSummary.ReadOnly
      ]
  object ListNetworksPaginated
      extends Effect[
        ListNetworksRequest,
        AwsError,
        zio.aws.managedblockchain.model.ListNetworksResponse.ReadOnly
      ]
  object DeleteMember
      extends Effect[
        DeleteMemberRequest,
        AwsError,
        zio.aws.managedblockchain.model.DeleteMemberResponse.ReadOnly
      ]
  object ListTagsForResource
      extends Effect[
        ListTagsForResourceRequest,
        AwsError,
        zio.aws.managedblockchain.model.ListTagsForResourceResponse.ReadOnly
      ]
  object TagResource
      extends Effect[
        TagResourceRequest,
        AwsError,
        zio.aws.managedblockchain.model.TagResourceResponse.ReadOnly
      ]
  object ListProposalVotes
      extends Stream[
        ListProposalVotesRequest,
        AwsError,
        zio.aws.managedblockchain.model.VoteSummary.ReadOnly
      ]
  object ListProposalVotesPaginated
      extends Effect[
        ListProposalVotesRequest,
        AwsError,
        zio.aws.managedblockchain.model.ListProposalVotesResponse.ReadOnly
      ]
  object ListInvitations
      extends Stream[
        ListInvitationsRequest,
        AwsError,
        zio.aws.managedblockchain.model.Invitation.ReadOnly
      ]
  object ListInvitationsPaginated
      extends Effect[
        ListInvitationsRequest,
        AwsError,
        zio.aws.managedblockchain.model.ListInvitationsResponse.ReadOnly
      ]
  object VoteOnProposal
      extends Effect[
        VoteOnProposalRequest,
        AwsError,
        zio.aws.managedblockchain.model.VoteOnProposalResponse.ReadOnly
      ]
  object RejectInvitation
      extends Effect[
        RejectInvitationRequest,
        AwsError,
        zio.aws.managedblockchain.model.RejectInvitationResponse.ReadOnly
      ]
  object CreateProposal
      extends Effect[
        CreateProposalRequest,
        AwsError,
        zio.aws.managedblockchain.model.CreateProposalResponse.ReadOnly
      ]
  object ListNodes
      extends Stream[
        ListNodesRequest,
        AwsError,
        zio.aws.managedblockchain.model.NodeSummary.ReadOnly
      ]
  object ListNodesPaginated
      extends Effect[
        ListNodesRequest,
        AwsError,
        zio.aws.managedblockchain.model.ListNodesResponse.ReadOnly
      ]
  val compose: URLayer[Proxy, ManagedBlockchain] = zio.ZIO
    .service[Proxy]
    .flatMap { proxy =>
      withRuntime[Proxy].map { rts =>
        new ManagedBlockchain {
          val api: ManagedBlockchainAsyncClient = null
          def withAspect[R1](newAspect: AwsCallAspect[R1], r: ZEnvironment[R1])
              : ManagedBlockchain = this
          def listProposals(request: ListProposalsRequest): ZStream[
            Any,
            AwsError,
            zio.aws.managedblockchain.model.ProposalSummary.ReadOnly
          ] = rts.unsafeRun(proxy(ListProposals, request))
          def listProposalsPaginated(request: ListProposalsRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.ListProposalsResponse.ReadOnly
          ] = proxy(ListProposalsPaginated, request)
          def getNetwork(request: GetNetworkRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.GetNetworkResponse.ReadOnly
          ] = proxy(GetNetwork, request)
          def createNode(request: CreateNodeRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.CreateNodeResponse.ReadOnly
          ] = proxy(CreateNode, request)
          def createMember(request: CreateMemberRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.CreateMemberResponse.ReadOnly
          ] = proxy(CreateMember, request)
          def updateNode(request: UpdateNodeRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.UpdateNodeResponse.ReadOnly
          ] = proxy(UpdateNode, request)
          def createNetwork(request: CreateNetworkRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.CreateNetworkResponse.ReadOnly
          ] = proxy(CreateNetwork, request)
          def getNode(request: GetNodeRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.GetNodeResponse.ReadOnly
          ] = proxy(GetNode, request)
          def deleteNode(request: DeleteNodeRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.DeleteNodeResponse.ReadOnly
          ] = proxy(DeleteNode, request)
          def listMembers(request: ListMembersRequest): ZStream[
            Any,
            AwsError,
            zio.aws.managedblockchain.model.MemberSummary.ReadOnly
          ] = rts.unsafeRun(proxy(ListMembers, request))
          def listMembersPaginated(request: ListMembersRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.ListMembersResponse.ReadOnly
          ] = proxy(ListMembersPaginated, request)
          def getProposal(request: GetProposalRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.GetProposalResponse.ReadOnly
          ] = proxy(GetProposal, request)
          def updateMember(request: UpdateMemberRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.UpdateMemberResponse.ReadOnly
          ] = proxy(UpdateMember, request)
          def untagResource(request: UntagResourceRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.UntagResourceResponse.ReadOnly
          ] = proxy(UntagResource, request)
          def getMember(request: GetMemberRequest): IO[AwsError, ReadOnly] =
            proxy(GetMember, request)
          def listNetworks(request: ListNetworksRequest): ZStream[
            Any,
            AwsError,
            zio.aws.managedblockchain.model.NetworkSummary.ReadOnly
          ] = rts.unsafeRun(proxy(ListNetworks, request))
          def listNetworksPaginated(request: ListNetworksRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.ListNetworksResponse.ReadOnly
          ] = proxy(ListNetworksPaginated, request)
          def deleteMember(request: DeleteMemberRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.DeleteMemberResponse.ReadOnly
          ] = proxy(DeleteMember, request)
          def listTagsForResource(request: ListTagsForResourceRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.ListTagsForResourceResponse.ReadOnly
          ] = proxy(ListTagsForResource, request)
          def tagResource(request: TagResourceRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.TagResourceResponse.ReadOnly
          ] = proxy(TagResource, request)
          def listProposalVotes(request: ListProposalVotesRequest): ZStream[
            Any,
            AwsError,
            zio.aws.managedblockchain.model.VoteSummary.ReadOnly
          ] = rts.unsafeRun(proxy(ListProposalVotes, request))
          def listProposalVotesPaginated(request: ListProposalVotesRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.ListProposalVotesResponse.ReadOnly
          ] = proxy(ListProposalVotesPaginated, request)
          def listInvitations(request: ListInvitationsRequest): ZStream[
            Any,
            AwsError,
            zio.aws.managedblockchain.model.Invitation.ReadOnly
          ] = rts.unsafeRun(proxy(ListInvitations, request))
          def listInvitationsPaginated(request: ListInvitationsRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.ListInvitationsResponse.ReadOnly
          ] = proxy(ListInvitationsPaginated, request)
          def voteOnProposal(request: VoteOnProposalRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.VoteOnProposalResponse.ReadOnly
          ] = proxy(VoteOnProposal, request)
          def rejectInvitation(request: RejectInvitationRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.RejectInvitationResponse.ReadOnly
          ] = proxy(RejectInvitation, request)
          def createProposal(request: CreateProposalRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.CreateProposalResponse.ReadOnly
          ] = proxy(CreateProposal, request)
          def listNodes(request: ListNodesRequest): ZStream[
            Any,
            AwsError,
            zio.aws.managedblockchain.model.NodeSummary.ReadOnly
          ] = rts.unsafeRun(proxy(ListNodes, request))
          def listNodesPaginated(request: ListNodesRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.ListNodesResponse.ReadOnly
          ] = proxy(ListNodesPaginated, request)
        }
      }
    }
    .toLayer
}

==> zio-aws-managedblockchain_2.12-5.17.166.3-sources.jar: zio/aws/managedblockchain/ManagedBlockchainMock.scala <==
package zio.aws.managedblockchain
import zio.aws.managedblockchain.model.GetMemberResponse.ReadOnly
import zio.mock.{Proxy, Mock}
import zio.aws.core.AwsError
import zio.aws.core.aspects.AwsCallAspect
import zio.{IO, ZEnvironment, URLayer}
import zio.aws.managedblockchain.model.{
  CreateMemberRequest,
  UpdateMemberRequest,
  GetNetworkRequest,
  RejectInvitationRequest,
  ListProposalVotesRequest,
  ListNodesRequest,
  ListMembersRequest,
  ListProposalsRequest,
  ListTagsForResourceRequest,
  UpdateNodeRequest,
  GetProposalRequest,
  CreateProposalRequest,
  GetMemberRequest,
  DeleteNodeRequest,
  ListInvitationsRequest,
  CreateNodeRequest,
  VoteOnProposalRequest,
  DeleteMemberRequest,
  UntagResourceRequest,
  GetNodeRequest,
  ListNetworksRequest,
  TagResourceRequest,
  CreateNetworkRequest
}
import software.amazon.awssdk.services.managedblockchain.ManagedBlockchainAsyncClient
import zio.stream.ZStream
object ManagedBlockchainMock extends Mock[ManagedBlockchain] {
  object ListProposals
      extends Stream[
        ListProposalsRequest,
        AwsError,
        zio.aws.managedblockchain.model.ProposalSummary.ReadOnly
      ]
  object ListProposalsPaginated
      extends Effect[
        ListProposalsRequest,
        AwsError,
        zio.aws.managedblockchain.model.ListProposalsResponse.ReadOnly
      ]
  object GetNetwork
      extends Effect[
        GetNetworkRequest,
        AwsError,
        zio.aws.managedblockchain.model.GetNetworkResponse.ReadOnly
      ]
  object CreateNode
      extends Effect[
        CreateNodeRequest,
        AwsError,
        zio.aws.managedblockchain.model.CreateNodeResponse.ReadOnly
      ]
  object CreateMember
      extends Effect[
        CreateMemberRequest,
        AwsError,
        zio.aws.managedblockchain.model.CreateMemberResponse.ReadOnly
      ]
  object UpdateNode
      extends Effect[
        UpdateNodeRequest,
        AwsError,
        zio.aws.managedblockchain.model.UpdateNodeResponse.ReadOnly
      ]
  object CreateNetwork
      extends Effect[
        CreateNetworkRequest,
        AwsError,
        zio.aws.managedblockchain.model.CreateNetworkResponse.ReadOnly
      ]
  object GetNode
      extends Effect[
        GetNodeRequest,
        AwsError,
        zio.aws.managedblockchain.model.GetNodeResponse.ReadOnly
      ]
  object DeleteNode
      extends Effect[
        DeleteNodeRequest,
        AwsError,
        zio.aws.managedblockchain.model.DeleteNodeResponse.ReadOnly
      ]
  object ListMembers
      extends Stream[
        ListMembersRequest,
        AwsError,
        zio.aws.managedblockchain.model.MemberSummary.ReadOnly
      ]
  object ListMembersPaginated
      extends Effect[
        ListMembersRequest,
        AwsError,
        zio.aws.managedblockchain.model.ListMembersResponse.ReadOnly
      ]
  object GetProposal
      extends Effect[
        GetProposalRequest,
        AwsError,
        zio.aws.managedblockchain.model.GetProposalResponse.ReadOnly
      ]
  object UpdateMember
      extends Effect[
        UpdateMemberRequest,
        AwsError,
        zio.aws.managedblockchain.model.UpdateMemberResponse.ReadOnly
      ]
  object UntagResource
      extends Effect[
        UntagResourceRequest,
        AwsError,
        zio.aws.managedblockchain.model.UntagResourceResponse.ReadOnly
      ]
  object GetMember extends Effect[GetMemberRequest, AwsError, ReadOnly]
  object ListNetworks
      extends Stream[
        ListNetworksRequest,
        AwsError,
        zio.aws.managedblockchain.model.NetworkSummary.ReadOnly
      ]
  object ListNetworksPaginated
      extends Effect[
        ListNetworksRequest,
        AwsError,
        zio.aws.managedblockchain.model.ListNetworksResponse.ReadOnly
      ]
  object DeleteMember
      extends Effect[
        DeleteMemberRequest,
        AwsError,
        zio.aws.managedblockchain.model.DeleteMemberResponse.ReadOnly
      ]
  object ListTagsForResource
      extends Effect[
        ListTagsForResourceRequest,
        AwsError,
        zio.aws.managedblockchain.model.ListTagsForResourceResponse.ReadOnly
      ]
  object TagResource
      extends Effect[
        TagResourceRequest,
        AwsError,
        zio.aws.managedblockchain.model.TagResourceResponse.ReadOnly
      ]
  object ListProposalVotes
      extends Stream[
        ListProposalVotesRequest,
        AwsError,
        zio.aws.managedblockchain.model.VoteSummary.ReadOnly
      ]
  object ListProposalVotesPaginated
      extends Effect[
        ListProposalVotesRequest,
        AwsError,
        zio.aws.managedblockchain.model.ListProposalVotesResponse.ReadOnly
      ]
  object ListInvitations
      extends Stream[
        ListInvitationsRequest,
        AwsError,
        zio.aws.managedblockchain.model.Invitation.ReadOnly
      ]
  object ListInvitationsPaginated
      extends Effect[
        ListInvitationsRequest,
        AwsError,
        zio.aws.managedblockchain.model.ListInvitationsResponse.ReadOnly
      ]
  object VoteOnProposal
      extends Effect[
        VoteOnProposalRequest,
        AwsError,
        zio.aws.managedblockchain.model.VoteOnProposalResponse.ReadOnly
      ]
  object RejectInvitation
      extends Effect[
        RejectInvitationRequest,
        AwsError,
        zio.aws.managedblockchain.model.RejectInvitationResponse.ReadOnly
      ]
  object CreateProposal
      extends Effect[
        CreateProposalRequest,
        AwsError,
        zio.aws.managedblockchain.model.CreateProposalResponse.ReadOnly
      ]
  object ListNodes
      extends Stream[
        ListNodesRequest,
        AwsError,
        zio.aws.managedblockchain.model.NodeSummary.ReadOnly
      ]
  object ListNodesPaginated
      extends Effect[
        ListNodesRequest,
        AwsError,
        zio.aws.managedblockchain.model.ListNodesResponse.ReadOnly
      ]
  val compose: URLayer[Proxy, ManagedBlockchain] = zio.ZLayer {
    zio.ZIO.service[Proxy].flatMap { proxy =>
      withRuntime[Proxy].map { rts =>
        new ManagedBlockchain {
          val api: ManagedBlockchainAsyncClient = null
          def withAspect[R1](newAspect: AwsCallAspect[R1], r: ZEnvironment[R1])
              : ManagedBlockchain = this
          def listProposals(request: ListProposalsRequest): ZStream[
            Any,
            AwsError,
            zio.aws.managedblockchain.model.ProposalSummary.ReadOnly
          ] = rts.unsafeRun(proxy(ListProposals, request))
          def listProposalsPaginated(request: ListProposalsRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.ListProposalsResponse.ReadOnly
          ] = proxy(ListProposalsPaginated, request)
          def getNetwork(request: GetNetworkRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.GetNetworkResponse.ReadOnly
          ] = proxy(GetNetwork, request)
          def createNode(request: CreateNodeRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.CreateNodeResponse.ReadOnly
          ] = proxy(CreateNode, request)
          def createMember(request: CreateMemberRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.CreateMemberResponse.ReadOnly
          ] = proxy(CreateMember, request)
          def updateNode(request: UpdateNodeRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.UpdateNodeResponse.ReadOnly
          ] = proxy(UpdateNode, request)
          def createNetwork(request: CreateNetworkRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.CreateNetworkResponse.ReadOnly
          ] = proxy(CreateNetwork, request)
          def getNode(request: GetNodeRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.GetNodeResponse.ReadOnly
          ] = proxy(GetNode, request)
          def deleteNode(request: DeleteNodeRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.DeleteNodeResponse.ReadOnly
          ] = proxy(DeleteNode, request)
          def listMembers(request: ListMembersRequest): ZStream[
            Any,
            AwsError,
            zio.aws.managedblockchain.model.MemberSummary.ReadOnly
          ] = rts.unsafeRun(proxy(ListMembers, request))
          def listMembersPaginated(request: ListMembersRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.ListMembersResponse.ReadOnly
          ] = proxy(ListMembersPaginated, request)
          def getProposal(request: GetProposalRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.GetProposalResponse.ReadOnly
          ] = proxy(GetProposal, request)
          def updateMember(request: UpdateMemberRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.UpdateMemberResponse.ReadOnly
          ] = proxy(UpdateMember, request)
          def untagResource(request: UntagResourceRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.UntagResourceResponse.ReadOnly
          ] = proxy(UntagResource, request)
          def getMember(request: GetMemberRequest): IO[AwsError, ReadOnly] =
            proxy(GetMember, request)
          def listNetworks(request: ListNetworksRequest): ZStream[
            Any,
            AwsError,
            zio.aws.managedblockchain.model.NetworkSummary.ReadOnly
          ] = rts.unsafeRun(proxy(ListNetworks, request))
          def listNetworksPaginated(request: ListNetworksRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.ListNetworksResponse.ReadOnly
          ] = proxy(ListNetworksPaginated, request)
          def deleteMember(request: DeleteMemberRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.DeleteMemberResponse.ReadOnly
          ] = proxy(DeleteMember, request)
          def listTagsForResource(request: ListTagsForResourceRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.ListTagsForResourceResponse.ReadOnly
          ] = proxy(ListTagsForResource, request)
          def tagResource(request: TagResourceRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.TagResourceResponse.ReadOnly
          ] = proxy(TagResource, request)
          def listProposalVotes(request: ListProposalVotesRequest): ZStream[
            Any,
            AwsError,
            zio.aws.managedblockchain.model.VoteSummary.ReadOnly
          ] = rts.unsafeRun(proxy(ListProposalVotes, request))
          def listProposalVotesPaginated(request: ListProposalVotesRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.ListProposalVotesResponse.ReadOnly
          ] = proxy(ListProposalVotesPaginated, request)
          def listInvitations(request: ListInvitationsRequest): ZStream[
            Any,
            AwsError,
            zio.aws.managedblockchain.model.Invitation.ReadOnly
          ] = rts.unsafeRun(proxy(ListInvitations, request))
          def listInvitationsPaginated(request: ListInvitationsRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.ListInvitationsResponse.ReadOnly
          ] = proxy(ListInvitationsPaginated, request)
          def voteOnProposal(request: VoteOnProposalRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.VoteOnProposalResponse.ReadOnly
          ] = proxy(VoteOnProposal, request)
          def rejectInvitation(request: RejectInvitationRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.RejectInvitationResponse.ReadOnly
          ] = proxy(RejectInvitation, request)
          def createProposal(request: CreateProposalRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.CreateProposalResponse.ReadOnly
          ] = proxy(CreateProposal, request)
          def listNodes(request: ListNodesRequest): ZStream[
            Any,
            AwsError,
            zio.aws.managedblockchain.model.NodeSummary.ReadOnly
          ] = rts.unsafeRun(proxy(ListNodes, request))
          def listNodesPaginated(request: ListNodesRequest): IO[
            AwsError,
            zio.aws.managedblockchain.model.ListNodesResponse.ReadOnly
          ] = proxy(ListNodesPaginated, request)
        }
      }
    }
  }
}
